You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ranger.apache.org by bo...@apache.org on 2015/01/05 07:36:47 UTC

[2/2] incubator-ranger git commit: Updated files containing Argus to Ranger.

Updated files containing Argus to Ranger.

Project: http://git-wip-us.apache.org/repos/asf/incubator-ranger/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-ranger/commit/97d8d803
Tree: http://git-wip-us.apache.org/repos/asf/incubator-ranger/tree/97d8d803
Diff: http://git-wip-us.apache.org/repos/asf/incubator-ranger/diff/97d8d803

Branch: refs/heads/master
Commit: 97d8d80361c0b6db22ceca6832e826f22dc3edb3
Parents: 8a9ebff
Author: Don Bosco Durai <bo...@apache.org>
Authored: Tue Dec 30 22:10:03 2014 -0800
Committer: Don Bosco Durai <bo...@apache.org>
Committed: Tue Dec 30 22:10:03 2014 -0800

----------------------------------------------------------------------
 DISCLAIMER.txt                                               | 3 +--
 .../authorization/hive/authorizer/RangerHiveAuthorizer.java  | 8 ++++----
 .../hive/authorizer/RangerHiveAuthorizerBase.java            | 2 +-
 security-admin/src/main/webapp/login.jsp                     | 2 +-
 storm-agent/scripts/uninstall.sh                             | 2 +-
 unixauthservice/conf.dist/unixauthservice.properties         | 2 +-
 6 files changed, 9 insertions(+), 10 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-ranger/blob/97d8d803/DISCLAIMER.txt
----------------------------------------------------------------------
diff --git a/DISCLAIMER.txt b/DISCLAIMER.txt
index 3e5ca07..4d8e175 100644
--- a/DISCLAIMER.txt
+++ b/DISCLAIMER.txt
@@ -12,5 +12,4 @@ fully endorsed by the ASF.
 For more information about the incubation status of the Apache Ranger project you
 can go to the following page:
 
-http://incubator.apache.org/argus/
-
+http://ranger.incubator.apache.org

http://git-wip-us.apache.org/repos/asf/incubator-ranger/blob/97d8d803/hive-agent/src/main/java/org/apache/ranger/authorization/hive/authorizer/RangerHiveAuthorizer.java
----------------------------------------------------------------------
diff --git a/hive-agent/src/main/java/org/apache/ranger/authorization/hive/authorizer/RangerHiveAuthorizerBase.java b/hive-agent/src/main/java/org/apache/ranger/authorization/hive/authorizer/RangerHiveAuthorizerBase.java
index 776646d..de43975 100644
--- a/hive-agent/src/main/java/org/apache/ranger/authorization/hive/authorizer/RangerHiveAuthorizerBase.java
+++ b/hive-agent/src/main/java/org/apache/ranger/authorization/hive/authorizer/RangerHiveAuthorizerBase.java
@@ -224,7 +224,7 @@ public abstract class RangerHiveAuthorizerBase implements HiveAuthorizer {
 	}
 
 	private void throwNotImplementedException(String method) throws HiveAuthzPluginException {
-		throw new HiveAuthzPluginException(method + "() not implemented in Argus HiveAuthorizer");
+		throw new HiveAuthzPluginException(method + "() not implemented in Ranger HiveAuthorizer");
 	}
 
 }

http://git-wip-us.apache.org/repos/asf/incubator-ranger/blob/97d8d803/security-admin/src/main/webapp/login.jsp
----------------------------------------------------------------------
diff --git a/security-admin/src/main/webapp/login.jsp b/security-admin/src/main/webapp/login.jsp
index 7610f9b..33fc339 100644
--- a/security-admin/src/main/webapp/login.jsp
+++ b/security-admin/src/main/webapp/login.jsp
@@ -60,7 +60,7 @@
 		================================================== -->
 		<section id="signin-container" style="margin-top: 4.5px;">
 			<div class="l-logo">
-				<img src="images/logo.png" alt="Argus logo">
+				<img src="images/logo.png" alt="Ranger logo">
 			</div>
 			<form action="" method="post" accept-charset="utf-8">
 				<fieldset>

http://git-wip-us.apache.org/repos/asf/incubator-ranger/blob/97d8d803/storm-agent/scripts/uninstall.sh
----------------------------------------------------------------------
diff --git a/storm-agent/scripts/uninstall.sh b/storm-agent/scripts/uninstall.sh
index 72a40f2..28b46fe 100644
--- a/storm-agent/scripts/uninstall.sh
+++ b/storm-agent/scripts/uninstall.sh
@@ -56,7 +56,7 @@ if [ ! -z ${ARCHIVE_FILE}.new ]
 then
 	cat ${ARCHIVE_FILE}.new > ${CONFIG_FILE}
 	rm -f ${ARCHIVE_FILE}.new
-	echo "Apache Argus Plugin has been uninstalled from Storm Service. Please restart Storm nimbus and ui services ..."
+	echo "Apache Ranger Plugin has been uninstalled from Storm Service. Please restart Storm nimbus and ui services ..."
 else
 	echo "ERROR: ${ARCHIVE_FILE}.new file has not created successfully."
 	exit 1

http://git-wip-us.apache.org/repos/asf/incubator-ranger/blob/97d8d803/unixauthservice/conf.dist/unixauthservice.properties
----------------------------------------------------------------------
diff --git a/unixauthservice/conf.dist/unixauthservice.properties b/unixauthservice/conf.dist/unixauthservice.properties
index 993f80c..e45b5a4 100644
--- a/unixauthservice/conf.dist/unixauthservice.properties
+++ b/unixauthservice/conf.dist/unixauthservice.properties
@@ -148,4 +148,4 @@ ldapGroupSync.userGroupNameAttribute =  memberof, ismemberof
 ldapGroupSync.username.caseConversion=lower
 ldapGroupSync.groupname.caseConversion=lower
 #user sync log path
-logdir=/var/log/argus-usersync
+logdir=/var/log/ranger/usersync
diff --git a/hive-agent/src/main/java/org/apache/ranger/authorization/hive/authorizer/RangerHiveAuthorizer.java b/hive-agent/src/main/java/org/apache/ranger/authorization/hive/authorizer/RangerHiveAuthorizer.java
index d797b1a..cc56f58 100644
--- a/hive-agent/src/main/java/org/apache/ranger/authorization/hive/authorizer/RangerHiveAuthorizer.java
+++ b/hive-agent/src/main/java/org/apache/ranger/authorization/hive/authorizer/RangerHiveAuthorizer.java
@@ -116,7 +116,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 								boolean             grantOption)
 										throws HiveAuthzPluginException, HiveAccessControlException {
 		if(! UpdateXaPoliciesOnGrantRevoke) {
-			throw new HiveAuthzPluginException("GRANT/REVOKE not supported in Argus HiveAuthorizer. Please use Argus Security Admin to setup access control.");
+			throw new HiveAuthzPluginException("GRANT/REVOKE not supported in Ranger HiveAuthorizer. Please use Ranger Security Admin to setup access control.");
 		}
 
 		boolean                isSuccess     = false;
@@ -164,7 +164,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 								 boolean             grantOption)
 										 throws HiveAuthzPluginException, HiveAccessControlException {
 		if(! UpdateXaPoliciesOnGrantRevoke) {
-			throw new HiveAuthzPluginException("GRANT/REVOKE not supported in Argus HiveAuthorizer. Please use Argus Security Admin to setup access control.");
+			throw new HiveAuthzPluginException("GRANT/REVOKE not supported in Ranger HiveAuthorizer. Please use Ranger Security Admin to setup access control.");
 		}
 
 		boolean                isSuccess     = false;
@@ -274,7 +274,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 				RangerHiveObjectAccessInfo hiveAccessObj = getObjectAccessInfo(hiveOpType, hiveObj, context, true);
 				
 				if(   hiveAccessObj != null
-				   && hiveAccessObj.getAccessType() != HiveAccessType.ADMIN // access check is performed at the Argus policy server, as a part of updating the permissions
+				   && hiveAccessObj.getAccessType() != HiveAccessType.ADMIN // access check is performed at the Ranger policy server, as a part of updating the permissions
 				   && !ret.contains(hiveAccessObj)) {
 					ret.add(hiveAccessObj);
 				}
@@ -286,7 +286,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 				RangerHiveObjectAccessInfo hiveAccessObj = getObjectAccessInfo(hiveOpType, hiveObj, context, false);
 				
 				if(   hiveAccessObj != null
-				   && hiveAccessObj.getAccessType() != HiveAccessType.ADMIN // access check is performed at the Argus policy server, as a part of updating the permissions
+				   && hiveAccessObj.getAccessType() != HiveAccessType.ADMIN // access check is performed at the Ranger policy server, as a part of updating the permissions
 				   && !ret.contains(hiveAccessObj)) {
 					ret.add(hiveAccessObj);
 				}

http://git-wip-us.apache.org/repos/asf/incubator-ranger/blob/97d8d803/hive-agent/src/main/java/org/apache/ranger/authorization/hive/authorizer/RangerHiveAuthorizerBase.java
----------------------------------------------------------------------